@@ -1,3 +1,6 @@
+import sys, os
+sys.path.append("C:/Users/" + os.getlogin() + "/scoop/apps/python/current/Lib/site-packages")
+
 from .randomhex import createDigest
 from .filterfile import filterFile
 from .extractlist import extractList
